pub struct RingArrayBuf<const N: usize> { /* private fields */ }Available on crate feature
extend only.Expand description
A generic ring buffer implementation using arrays of the size of the power of two as internal buffers.
N must be a power of 2.