pub trait LhaDecoderConfig {
type RingBuffer: RingBuffer;
const HISTORY_BITS: u32;
const OFFSET_BITS: u32;
}Expand description
LHArc version 2 configuration for LhaV2Decoder.
Required Associated Constants
Sourceconst HISTORY_BITS: u32
const HISTORY_BITS: u32
The code lengths table size for building the offset tree.
The value of this number is determining the maximum size of the history sliding window. E.g for 8192 byte sliding window set this to 14.
This has to be no greater than MAX_HISTORY_BITS.
Sourceconst OFFSET_BITS: u32
const OFFSET_BITS: u32
This number of bits is read to determine the size of the actual offset code length table.
This is currently limited to be between 1 and 5 inclusive.
Required Associated Types
Sourcetype RingBuffer: RingBuffer
type RingBuffer: RingBuffer
A ring buffer object of size equal to 2 to the power of (Self::HISTORY_BITS - 1).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".